OC.L10N.register(
    "core",
    {
    "Please select a file." : "Izberite datoteko.",
    "File is too big" : "Datoteka je prevelika",
    "The selected file is not an image." : "Izbrana datoteka ni slika.",
    "The selected file cannot be read." : "Izbrane datoteke ni mogoče prebrati.",
    "Invalid file provided" : "Predložena je neveljavna datoteka",
    "No image or file provided" : "Ni podane datoteke ali slike",
    "Unknown filetype" : "Neznana vrsta datoteke",
    "Invalid image" : "Neveljavna slika",
    "An error occurred. Please contact your admin." : "Prišlo je do napake. Stopite v stik s skrbnikom sistema.",
    "No temporary profile picture available, try again" : "Na voljo ni nobene začasne slike za profil. Poskusite znova.",
    "No crop data provided" : "Ni podanih podatkov obreza",
    "No valid crop data provided" : "Podani so neveljavni podatki za obrez slike ",
    "Crop is not square" : "Obrez ni pravokoten",
    "Could not complete login" : "Prijave ni mogoče dokončati",
    "Password reset is disabled" : "Ponastavitev gesla je onemogočena",
    "Couldn't reset password because the token is invalid" : "Zaradi neustreznega žetona ni mogoče ponastaviti gesla.",
    "Couldn't reset password because the token is expired" : "Ni mogoče ponastaviti gesla, ker je žeton potekel.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Ni mogoče poslati elektronskega sporočila za ponastavitev gesla, ker ni navedenega elektronskega naslova. Stopite v stik s skrbnikom sistema.",
    "%s password reset" : "Ponastavitev gesla %s",
    "Password reset" : "Ponastavitev gesla",
    "Reset your password" : "Ponastavi geslo",
    "Couldn't send reset email. Please contact your administrator." : "Ni mogoče poslati elektronskega sporočila za ponastavitev. Stopite v stik s skrbnikom sistema.",
    "Couldn't send reset email. Please make sure your username is correct." : "Ni mogoče poslati elektronskega sporočila. Prepričajte se, da je uporabniško ime pravilno.",
    "Some of your link shares have been removed" : "Nekatere povezave za souporabo so bile odstranjene.",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Zaradi varnostnih razlogov so bile nekatere povezave odstranjene. Več podrobnosti je na voljo v uradno izdanem opozorilu.",
    "Preparing update" : "Poteka pripravljanje posodobitve",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Posodobitev sistema je treba izvesti prek ukazne vrstice, ker je nastavitev samodejne posodobitve v config.php onemogočena.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Poteka preverjanje razpredelnice %s",
    "Turned on maintenance mode" : "Vzdrževalni način je omogočen",
    "Turned off maintenance mode" : "Vzdrževalni način je onemogočen",
    "Maintenance mode is kept active" : "Vzdrževalni način je še vedno dejaven",
    "Updating database schema" : "Poteka posodabljanje sheme podatkovne zbirke",
    "Updated database" : "Posodobljena podatkovna zbirka",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Poteka preverjanje, ali je shemo podatkovne zbirke mogoče posodobiti (zaradi velikosti je lahko opravilo dolgotrajno).",
    "Checked database schema update" : "Izbrana posodobitev sheme podatkovne zbirke",
    "Checking updates of apps" : "Poteka preverjanje za posodobitve programov",
    "Checking for update of app \"%s\" in appstore" : "Preverjam posodobitev za aplikacijo \"%s\" v trgovini",
    "Update app \"%s\" from appstore" : "Posodobi aplikacijo \"%s\" iz trgovine",
    "Checked for update of app \"%s\" in appstore" : "Preverjena posodobitev za \"%s\" v trgovini",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Poteka preverjanje, ali je shemo podatkovne zbirke za %s mogoče posodobiti (trajanje posodobitve je odvisno od velikosti zbirke).",
    "Checked database schema update for apps" : "Izbrana posodobitev sheme podatkovne zbirke za programe",
    "Updated \"%1$s\" to %2$s" : "Posodabljanje »%1$s« na različico %2$s",
    "Set log level to debug" : "Nastavi raven beleženja za razhroščevanje",
    "Reset log level" : "Počisti raven beleženja",
    "Starting code integrity check" : "Začenjanje preverjanja stanja kode",
    "Finished code integrity check" : "Preverjanje stanja kode je končano",
    "%s (incompatible)" : "%s (neskladno)",
    "Following apps have been disabled: %s" : "Onemogočeni so programi: %s",
    "Already up to date" : "Sistem je že posodobljen",
    "Very weak password" : "Zelo šibko geslo",
    "Weak password" : "Šibko geslo",
    "So-so password" : "Slabo geslo",
    "Good password" : "Dobro geslo",
    "Strong password" : "Odlično geslo",
    "Error occurred while checking server setup" : "Prišlo je do napake med preverjanjem nastavitev strežnika",
    "Shared" : "V souporabi",
    "Shared with" : "V skupni rabi z",
    "Shared by" : "V souporabi od",
    "Choose a password for the public link" : "Izberite geslo za javno povezavo",
    "Choose a password for the public link or press the \"Enter\" key" : "Izberite geslo za javno povezavo ali pritisnite \"Enter\"",
    "Copied!" : "Naslov je kopiran!",
    "Copy link" : "Kopiraj povezavo",
    "Not supported!" : "Ni podprto!",
    "Press ⌘-C to copy." : "Pritisni ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisni Ctrl-C za kopiranje.",
    "Copy" : "Kopiraj",
    "Resharing is not allowed" : "Nadaljnja souporaba ni dovoljena",
    "Link" : "Povezava",
    "Password protect" : "Zaščiti z geslom",
    "Password" : "Geslo",
    "Allow editing" : "Dovoli urejanje",
    "Email link to person" : "Posreduj povezavo po elektronski pošti",
    "Send" : "Pošlji",
    "Allow upload and editing" : "Dovoli pošiljanje in urejanje",
    "Read only" : "Samo branje",
    "File drop (upload only)" : "Povleci datoteke (samo nalaganje)",
    "Set expiration date" : "Nastavi datum preteka",
    "Expiration" : "Datum preteka",
    "Expiration date" : "Datum preteka",
    "Note to recipient" : "Pošlji opombo prejemniku",
    "Unshare" : "Prekliči souporabo",
    "Add another link" : "Dodaj novo povezavo",
    "Share to {name}" : "Deli z {name}",
    "Share link" : "Povezava do mape souporabe",
    "Could not unshare" : "Ni mogoče preklicati souporabe",
    "Shared with you and the group {group} by {owner}" : "{owner} omogoči souporabo z vami in s skupino {group}.",
    "Shared with you by {owner}" : "{owner} vam omogoči souporabo",
    "group" : "skupina",
    "remote" : "oddaljeno",
    "remote group" : "oddaljena skupina",
    "email" : "elektronska pošta",
    "conversation" : "pogovor",
    "shared by {sharer}" : "deli {sharer}",
    "Can reshare" : "Lahko deli naprej",
    "Can edit" : "Lahko ureja",
    "Can create" : "Lahko ustvari",
    "Can change" : "Lahko spremeni",
    "Can delete" : "Lahko izbriše",
    "Access control" : "Nadzor dostopa",
    "Error while sharing" : "Napaka med omogočanjem souporabe",
    "Share details could not be loaded for this item." : "Podrobnosti souporabe za te predmet ni mogoče naložiti.",
    "No users or groups found for {search}" : "Ni najdenih uporabnikov ali skupin za {search}",
    "No users found for {search}" : "Ni uporabnikov, skladnih z iskalnim nizom {search}",
    "An error occurred. Please try again" : "Prišlo je do napake. Poskusite znova.",
    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
    "Share" : "Souporaba",
    "Name or email address..." : "Ime ali e-poštni naslov...",
    "Name or federated cloud ID..." : "Ime ali ID oblaka...",
    "Name, federated cloud ID or email address..." : "Ime, ID oblaka ali e-poštni naslov...",
    "Name..." : "Ime ...",
    "Error" : "Napaka",
    "Error removing share" : "Napaka odstranjevanja souporabe",
    "Non-existing tag #{tag}" : "Neobstoječa oznaka #{tag}",
    "restricted" : "omejeno",
    "invisible" : "nevidno",
    "({scope})" : "({scope})",
    "Delete" : "Izbriši",
    "Rename" : "Preimenuj",
    "Collaborative tags" : "Oznake sodelovanja",
    "No tags found" : "Ni najdenih oznak",
    "unknown text" : "neznano besedilo",
    "Hello world!" : "Pozdravljen svet!",
    "sunny" : "sončno",
    "Hello {name}, the weather is {weather}" : "Pozdravljeni, {name}, vreme je {weather}",
    "Hello {name}" : "Pozdravljeni, {name}",
    "new" : "novo",
    "_download %n file_::_download %n files_" : ["prejmi %n datoteko","prejmi %n datoteki","prejmi %n datoteke","prejmi %n datotek"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Posodobitev je v teku. Če zapustiš to stran, lahko, v določenih okoljih, prekineš proces",
    "Update to {version}" : "Posodobi na {version}",
    "An error occurred." : "Prišlo je do napake.",
    "Please reload the page." : "Stran je treba osvežiti.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Posodobitev je spodletela. Več podrobnosti o napaki je <a href=\"{url}\">objavljenih na forumu</a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Posodobitev je spodletela. Pošljite poročilo o napaki <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">skupnosti Nextcloud</a>.",
    "Continue to Nextcloud" : "Nadaljuj na Nextcloud",
    "Searching other places" : "Poteka iskanje na drugih mestih",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} rezultat v drugih mapah","{count} rezultata v drugih mapah","{count} rezultatov v drugih mapah","{count} rezultatov v drugih mapah"],
    "Server side authentication failed!" : "Overitev na strani strežnika je spodletela!",
    "Please contact your administrator." : "Stopite v stik s skrbnikom sistema.",
    "An internal error occurred." : "Prišlo je do notranje napake.",
    "Please try again or contact your administrator." : "Poskusite znova ali pa stopite v stik s skrbnikom sistema.",
    "Username or email" : "Uporabniško ime ali elektronski naslov",
    "Log in" : "Prijava",
    "Logging in …" : "Prijava...",
    "Reset password" : "Ponastavi geslo",
    "Password can not be changed. Please contact your administrator." : "Gesla ni mogoče spremeniti. Stopite v stik s skrbnikom.",
    "Forgot password?" : "Ali ste pozabili geslo?",
    "Settings" : "Nastavitve",
    "Could not load your contacts" : "Stikov ni mogoče naložiti",
    "Search contacts …" : "Poišči med stiki ...",
    "No contacts found" : "Ni najdenih stikov",
    "Show all contacts …" : "Prikaži vse stike ...",
    "Loading your contacts …" : "Poteka nalaganje stikov ...",
    "Looking for {term} …" : "Poteka iskanje {term} …",
    "No" : "Ne",
    "Yes" : "Da",
    "No files in here" : "Tukaj ni datotek",
    "Name" : "Ime",
    "Size" : "Velikost",
    "Modified" : "Spremenjeno",
    "{newName} already exists" : "{newName} že obstaja",
    "Choose" : "Izbor",
    "Move" : "Premakni",
    "Error loading file picker template: {error}" : "Napaka nalaganja predloge izbirnika datotek: {error}",
    "OK" : "V redu",
    "Error loading message template: {error}" : "Napaka nalaganja predloge sporočil: {error}",
    "read-only" : "le za branje",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} spor datotek","{count} spora datotek","{count} spori datotek","{count} sporov datotek"],
    "One file conflict" : "En spor datotek",
    "New Files" : "Nove datoteke",
    "Already existing files" : "Obstoječe datoteke",
    "Which files do you want to keep?" : "Katere datoteke želite ohraniti?",
    "If you select both versions, the copied file will have a number added to its name." : "Če izberete obe različici, bo k imenu kopirane datoteke dodana številka.",
    "Cancel" : "Prekliči",
    "Continue" : "Nadaljuj",
    "(all selected)" : "(vse izbrano)",
    "({count} selected)" : "({count} izbranih)",
    "Error loading file exists template" : "Napaka nalaganja predloge obstoječih datotek",
    "Pending" : "Na čakanju",
    "Copy to {folder}" : "Kopiraj v {folder}",
    "Move to {folder}" : "Premakni v {folder}",
    "Saving..." : "Poteka shranjevanje ...",
    "Authentication required" : "Opravilo zahteva overitev!",
    "This action requires you to confirm your password" : "Opravilo zahteva potrditev z vpisom skrbniškega gesla.",
    "Confirm" : "Potrdi",
    "Failed to authenticate, try again" : "Napaka pri preverjanju prisotnosti, poskusi znova",
    "seconds ago" : "pred nekaj sekundami",
    "Connection to server lost" : "Povezava s strežnikom spodletela",
    "View changelog" : "Ogled dnevnika sprememb",
    "No action available" : "Ni razpoložljivih dejanj",
    "Error fetching contact actions" : "Prišlo je do napake med pridobivanjem dejanj stikov",
    "Personal" : "Osebno",
    "Users" : "Uporabniki",
    "Apps" : "Programi",
    "Admin" : "Skrbništvo",
    "Help" : "Pomoč",
    "Access forbidden" : "Dostop je prepovedan",
    "File not found" : "Datoteke ni mogoče najti",
    "Internal Server Error" : "Notranja  napaka strežnika",
    "More details can be found in the server log." : "Več podrobnosti je zabeleženih v dnevniški datoteki strežnika.",
    "Technical details" : "Tehnične podrobnosti",
    "Remote Address: %s" : "Oddaljen naslov: %s",
    "Request ID: %s" : "ID zahteve: %s",
    "Type: %s" : "Vrsta: %s",
    "Code: %s" : "Koda: %s",
    "Message: %s" : "Sporočilo: %s",
    "File: %s" : "Datoteka: %s",
    "Line: %s" : "Vrstica: %s",
    "Trace" : "Sledenje povezav",
    "Security warning" : "Varnostno opozorilo",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Podatkovna mapa in datoteke so najverjetneje javno dostopni preko interneta, saj datoteka .htaccess ni ustrezno nastavljena.",
    "Create an <strong>admin account</strong>" : "Ustvari <strong>skrbniški račun</strong>",
    "Username" : "Uporabniško ime",
    "Storage & database" : "Shramba in podatkovna zbirka",
    "Data folder" : "Podatkovna mapa",
    "Configure the database" : "Nastavi podatkovno zbirko",
    "Only %s is available." : "Le %s je na voljo.",
    "Install and activate additional PHP modules to choose other database types." : "Namestite in omogočite dodatne module PHP za izbor drugih vrst podatkovnih zbirk.",
    "For more details check out the documentation." : "Za več podrobnosti preverite dokumentacijo.",
    "Database user" : "Uporabnik podatkovne zbirke",
    "Database password" : "Geslo podatkovne zbirke",
    "Database name" : "Ime podatkovne zbirke",
    "Database tablespace" : "Razpredelnica podatkovne zbirke",
    "Database host" : "Gostitelj podatkovne zbirke",
    "Performance warning" : "Opozorilo učinkovitosti delovanja",
    "Finish setup" : "Končaj nastavitev",
    "Finishing …" : "Poteka zaključevanje opravila ...",
    "Need help?" : "Ali potrebujete pomoč?",
    "See the documentation" : "Preverite dokumentacijo",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Program zahteva podporo JavaScript za pravilno delovanje. Med nastavitvami omogočite {linkstart}JavaScript{linkend} in osvežite spletno stran.",
    "More apps" : "Več programov",
    "Search" : "Poišči",
    "Reset search" : "Ponastavi iskanje",
    "Settings menu" : "Meni nastavitev",
    "Confirm your password" : "Potrdi svoje geslo",
    "App token" : "Ključ aplikacije",
    "Grant access" : "Odobri dostop",
    "New password" : "Novo geslo",
    "New Password" : "Novo geslo",
    "Two-factor authentication" : "Dvo-stopenjska overitev",
    "Use backup code" : "Uporabi rezervno šifro",
    "Cancel log in" : "Prekini prijavo",
    "Error while validating your second factor" : "Napaka med preverjanjem drugega koraka",
    "App update required" : "Zahtevana je posodobitev programa",
    "%1$s will be updated to version %2$s" : "Okolje %1$s bo posodobljeno na različico %2$s",
    "These apps will be updated:" : "Posodobljeni bodo programi:",
    "These incompatible apps will be disabled:" : "Zaradi neskladnosti bodo onemogočeni:",
    "The theme %s has been disabled." : "Tema %s je onemogočena za uporabo.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pred nadaljevanjem se prepričajte, da je ustvarjena varnostna kopija podatkovne zbirke, nastavitvenih datotek in podatkovne mape.",
    "Start update" : "Začni posodobitev",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Za razreševanje časovnih zahtev večjih namestitev lahko uporabite ukaz iz namestitvene mape:",
    "Detailed logs" : "Podrobni dnevniški zapisi",
    "Update needed" : "Zahtevana je posodobitev",
    "Upgrade via web on my own risk" : "Posodobi preko spleta na moje tveganje",
    "This %s instance is currently in maintenance mode, which may take a while." : "Strežnik %s je trenutno v načinu vzdrževanja, kar lahko zadrži izvajanje postopka.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Stopite v stik s skrbnikom sistema, če se bo sporočilo še naprej nepričakovano prikazovalo.",
    "Updated \"%s\" to %s" : "Datoteka \"%s\" je posodobljena na %s",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Med preverjanjem celovitosti kode je prišlo do napak. Več podrobnosti …</a>",
    "Dismiss" : "Opusti",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Povezava za ponastavitev gesla je bila poslana na naveden elektronski naslov. V kolikor sporočila ne prejmete v kratkem, preverite tudi mapo neželene pošte.<br> Če sporočila ni niti v tej mapi, stopite v stik s skrbnikom.",
    "I know what I'm doing" : "Vem, kaj delam!",
    "Sending email …" : "Poteka pošiljanje elektronske pošte ...",
    "Copy URL" : "Kopiraj naslov URL",
    "Enable" : "Omogoči",
    "{sharee} (group)" : "{sharee} (skupina)",
    "{sharee} (remote)" : "{sharee} (oddaljeno)",
    "{sharee} (email)" : "{sharee} (email)",
    "The specified document has not been found on the server." : "Navedenega dokumenta na strežniku ni mogoče najti.",
    "You can click here to return to %s." : "S klikom na povezavo boste vrnjeni na %s.",
    "SQLite will be used as database." : "Kot podatkovna zbirka bo uporabljena zbirka SQLite",
    "For larger installations we recommend to choose a different database backend." : "Za večje namestitve je priporočljivo uporabiti drug ozadnji program zbirke podatkov.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Uporaba SQLite ni priporočljiva iz varnostnih razlogov, še posebej če se sistem krajevno usklajuje z namizjem prek odjemalca.",
    "Wrong password." : "Napačno geslo!",
    "Redirecting …" : "Poteka preusmerjanje ...",
    "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Na tvojem računu je vključena napredna varnost. Prosim, prijavi se z drugim korakom.",
    "Further information how to configure this can be found in the %sdocumentation%s." : "Podrobnosti o nastavitvah je mogoče najti v %sdokumentaciji%s.",
    "%s will be updated to version %s" : "Okolje %s bo posodobljeno na različico %s.",
    "This page will refresh itself when the %s instance is available again." : "Stran bo osvežena, ko bo %s spet na voljo.",
    "Thank you for your patience." : "Hvala za potrpežljivost!"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
